@@ -1,6 +1,6 @@
 /*  
     gen_html.c - Part of psiconv, a PSION 5 file formats converter
-    Copyright (c) 1999-2005  Frodo Looijaard <frodo@frodo.looijaard.name>
+    Copyright (c) 1999-2014  Frodo Looijaard <frodo@frodo.looijaard.name>
                                                                                 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -247,7 +247,7 @@ void paragraph(const psiconv_config config, psiconv_list list,
 	  fputs("Out of memory error\n",stderr);
 	  exit(1);
 	}
-	memcpy(text,para->text+charnr,len * sizeof(*text));
+	memcpy(text,para->text+start,len * sizeof(*text));
 	text[len] = 0;
 	characters(config,list,text,layout->layout,enc);
 	free(text);
