@@ -1,6 +1,6 @@
 /*
  * gen_image.c - Part of psiconv, a PSION 5 file formats converter
- * Copyright (c) 1999-2005  Frodo Looijaard <frodo@frodo.looijaard.name>
+ * Copyright (c) 1999-2014  Frodo Looijaard <frodo@frodo.looijaard.name>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,9 +89,9 @@ void image_to_list(psiconv_list list,Image *image,const char *dest)
   ImageInfo *image_info;
   ExceptionInfo exc;
   size_t length;
-  char *data;
+  unsigned char *data;
   int i;
- 
+
   strcpy(image->magick,dest);
   image_info = CloneImageInfo(NULL);
   GetExceptionInfo(&exc);
@@ -235,18 +235,25 @@ void init_image(void)
 {
   struct fileformat_s ff;
 #if IMAGEMAGICK
-  const MagickInfo *mi;
+  const MagickInfo **mi;
+  int i;
+#if IMAGEMAGICK_API == 100
+  InitializeMagick(NULL);
+#endif
   ff.output = gen_image;
-  for (mi = GetMagickFileList(); mi ; mi = mi->next) {
-    if (mi->encoder) {
-      ff.name = strdup(mi->name);
-      ff.description = strdup(mi->description);
+  mi = GetMagickFileList();
+  i = 0;
+  while (mi[i]) {
+    if (mi[i]->encoder) {
+      ff.name = strdup(mi[i]->name);
+      ff.description = strdup(mi[i]->description);
       ff.supported_format = FORMAT_CLIPART_SINGLE | FORMAT_MBM_SINGLE | 
 	                    FORMAT_SKETCH;
-      if (mi->adjoin) 
+      if (mi[i]->adjoin) 
 	ff.supported_format |= FORMAT_MBM_MULTIPLE | FORMAT_CLIPART_MULTIPLE;
       psiconv_list_add(fileformat_list,&ff);
     }
+    i++;
   }
 #endif
 }
