@@ -1,5 +1,5 @@
 /*  gen_html.c - Part of psiconv, a PSION 5 file formats converter
-    Copyright (c) 1999-2004  Frodo Looijaard <frodol@dds.nl>
+    Copyright (c) 1999-2014  Frodo Looijaard <frodo@frodo.looijaard.name>
                                                                                 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -719,7 +719,7 @@ int gen_xhtml(const psiconv_config config, psiconv_list list,
 }
                                                                                 
 
-static struct fileformat_s ffs[] =
+static struct fileformat_s fileformats[] =
   {
     {
       "XHTML",
@@ -739,6 +739,6 @@ static struct fileformat_s ffs[] =
 void init_xhtml(void)
 {
   int i;
-  for (i = 0; ffs[i].name; i++)
-    psiconv_list_add(fileformat_list,ffs+i);
+  for (i = 0; fileformats[i].name; i++)
+    psiconv_list_add(fileformat_list,fileformats+i);
 }
