@@ -1,6 +1,6 @@
 /*
     magick-aux.h - Part of psiconv, a PSION 5 file formats converter
-    Copyright (c) 2000-2004  Frodo Looijaard <frodo@frodo.looijaard.name>
+    Copyright (c) 2000-2014  Frodo Looijaard <frodo@frodo.looijaard.name>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,8 +32,14 @@
 #include <time.h>
 #include <magick/api.h>
 
-#endif /* IMAGEMAGICK_OLD */
+#endif /* IMAGEMAGICK_API == 1 */
 
-extern const MagickInfo * GetMagickFileList(void);
+#if IMAGEMAGICK_API == 100
+
+#define DestroyImages DestroyImageList
+
+#endif
+
+extern const MagickInfo ** GetMagickFileList(void);
 
 #endif /* IMAGEMAGICK */
